==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1alpha1VolumeAttachmentFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1alpha1VolumeAttachmentFluent<A extends V1alpha1VolumeAttachmentFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> editMetadata();
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1VolumeAttachmentSpec getSpec();
    public V1alpha1VolumeAttachmentSpec buildSpec();
    public A withSpec(V1alpha1VolumeAttachmentSpec spec);
    public Boolean hasSpec();
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> withNewSpec();
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> withNewSpecLike(V1alpha1VolumeAttachmentSpec item);
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> editSpec();
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> editOrNewSpec();
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> editOrNewSpecLike(V1alpha1VolumeAttachmentSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1VolumeAttachmentStatus getStatus();
    public V1alpha1VolumeAttachmentStatus buildStatus();
    public A withStatus(V1alpha1VolumeAttachmentStatus status);
    public Boolean hasStatus();
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> withNewStatus();
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> withNewStatusLike(V1alpha1VolumeAttachmentStatus item);
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> editStatus();
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> editOrNewStatus();
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> editOrNewStatusLike(V1alpha1VolumeAttachmentStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1alpha1VolumeAttachmentFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1VolumeAttachmentSpecFluent<V1alpha1VolumeAttachmentFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1VolumeAttachmentStatusFluent<V1alpha1VolumeAttachmentFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1alpha1VolumeAttachmentFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1alpha1VolumeAttachmentFluent<A extends V1alpha1VolumeAttachmentFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> editMetadata();
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1VolumeAttachmentFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1VolumeAttachmentSpec getSpec();
    public V1alpha1VolumeAttachmentSpec buildSpec();
    public A withSpec(V1alpha1VolumeAttachmentSpec spec);
    public Boolean hasSpec();
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> withNewSpec();
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> withNewSpecLike(V1alpha1VolumeAttachmentSpec item);
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> editSpec();
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> editOrNewSpec();
    public V1alpha1VolumeAttachmentFluent.SpecNested<A> editOrNewSpecLike(V1alpha1VolumeAttachmentSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1VolumeAttachmentStatus getStatus();
    public V1alpha1VolumeAttachmentStatus buildStatus();
    public A withStatus(V1alpha1VolumeAttachmentStatus status);
    public Boolean hasStatus();
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> withNewStatus();
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> withNewStatusLike(V1alpha1VolumeAttachmentStatus item);
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> editStatus();
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> editOrNewStatus();
    public V1alpha1VolumeAttachmentFluent.StatusNested<A> editOrNewStatusLike(V1alpha1VolumeAttachmentStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1alpha1VolumeAttachmentFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1VolumeAttachmentSpecFluent<V1alpha1VolumeAttachmentFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1VolumeAttachmentStatusFluent<V1alpha1VolumeAttachmentFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
